@@ -25,9 +25,11 @@ PCA <- function(data, type = 1) {
   
   MC <- cov(data) # Matriz de Covariancia
   
+  num.comp <- min(dim(data)) # numero de componentes
+  
   ## Encontrando a Matriz de Decomposicao Expectral
   MAV <- eigen(MC) # Encontra a matriz de autovalor e autovetor
-  MAutoVlr <- MAV$values  # Matriz de Autovalores - Variancias
+  MAutoVlr <- MAV$values[1:num.comp]  # Matriz de Autovalores - Variancias
   MAutoVec <- MAV$vectors # Matriz de Autovetores - Componentes Principais
   
   ## Matriz das Variancias
@@ -41,15 +43,15 @@ PCA <- function(data, type = 1) {
   ## Matriz de Autovetores,ou seja, os Componentes Principais
   colnames(MAutoVec) <- paste("Comp.", 1:nrow(MC), sep = " ")
   rownames(MAutoVec) <- colnames(data)  
-  
+
   ## Covariancia dos Componentes Principais com as Variaveis Originais
   VCP <- diag(MAutoVlr,nrow(MC),ncol(MC))%*%t(MAutoVec)
-  rownames(VCP) <- paste("Comp", 1:length(MAutoVlr))
+  rownames(VCP) <- paste("Comp", 1:nrow(MC))
   
   ## Correlacao dos Componentes Principais com as Variaveis Originais
   CCP <- diag(sqrt(MAutoVlr),nrow(MC),ncol(MC))%*%t(MAutoVec)%*%diag(1/sqrt(diag(MC)),nrow(MC),ncol(MC))
   colnames(CCP) <- colnames(data) # Nomeia as linhas
-  rownames(CCP) <- paste("Comp", 1:length(MAutoVlr))
+  rownames(CCP) <- paste("Comp", 1:nrow(MC))
   
   Esc = as.matrix(data)%*%MAutoVec # Escores do componentes principais
   rownames(Esc) <- rownames(data)
